| gen_simulated_data | R Documentation |
The function simulates one sample's underlying somatic point mutations and copy number aberrations and creates vcf files formatted for UNMASC. Additional files created include bed files defining chromosome lengths, centromere regions, and target regions.
gen_simulated_data(
outdir,
purity = NULL,
cn_state = NULL,
num_loci = 10000,
num_normals = 20,
AA_vaf = 0.002,
mean_DP = 500,
oxog_vaf = 0.01,
ffpe_vaf = 0.1,
max_PSI = 0.02,
show_plot = TRUE,
seed = NULL
)
outdir |
Character string specifying the output directory. |
purity |
Tumor purity. By default, |
cn_state |
A R data.frame containing copy number states
with columns |
num_loci |
A positive integer for the number of tumor only variant loci simulated. |
num_normals |
A positive integer for the number of unmatched normal controls to simulate. |
AA_vaf |
The mean non-zero variant allele frequency for homozygous reference positions. |
mean_DP |
A positve numeric value for the mean depth of variant calls. |
oxog_vaf |
A positive numeric value for the expected allele frequency of oxoG variants. |
ffpe_vaf |
A positive numeric value for the expected allele frequency of FFPE variants. |
max_PSI |
A positive numeric value for the maximum overdispersion in the beta-binomial distribution. |
show_plot |
By default, set to |
seed |
A numeric seed value. If |
A list of simulated data including vcfs, filepaths, target BED file, dictionary chrom BED file, gender indicator to reflect the data type and format UNMASC is expecting.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.